import React, { HTMLAttributes } from 'react';
export declare type BPObject = {
    span: 'auto' | number | boolean;
    offset: number;
    order: 'first' | 'last' | number;
};
export interface CColProps extends HTMLAttributes<HTMLDivElement> {
    /**
     * A string of all className you want applied to the base component. [docs]
     */
    className?: string;
    /**
     * The number of columns/offset/order on extra small devices (<576px). [docs]
     *
     * @type { 'auto' | number | boolean | { span: 'auto' | number | boolean } | { offset: number } | { order: 'first' | 'last' | number }}
     */
    xs?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on small devices (<768px). [docs]
     *
     * @type { 'auto' | number | boolean | { span: 'auto' | number | boolean } | { offset: number } | { order: 'first' | 'last' | number }}
     */
    sm?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on medium devices (<992px). [docs]
     *
     * @type { 'auto' | number | boolean | { span: 'auto' | number | boolean } | { offset: number } | { order: 'first' | 'last' | number }}
     */
    md?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on large devices (<1200px). [docs]
     *
     * @type { 'auto' | number | boolean | { span: 'auto' | number | boolean } | { offset: number } | { order: 'first' | 'last' | number }}
     */
    lg?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on X-Large devices (<1400px). [docs]
     *
     * @type { 'auto' | number | boolean | { span: 'auto' | number | boolean } | { offset: number } | { order: 'first' | 'last' | number }}
     */
    xl?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on XX-Large devices (≥1400px). [docs]
     *
     * @type { 'auto' | number | boolean | { span: 'auto' | number | boolean } | { offset: number } | { order: 'first' | 'last' | number }}
     */
    xxl?: 'auto' | number | boolean | BPObject;
}
export declare const CCol: React.ForwardRefExoticComponent<CColProps & React.RefAttributes<HTMLDivElement>>;
