import React, { HTMLAttributes } from 'react';
export declare type BPObject = {
    cols?: 'auto' | number;
    gutter?: number;
    gutterX?: number;
    gutterY?: number;
};
export interface CRowProps extends HTMLAttributes<HTMLDivElement> {
    /**
     * A string of all className you want applied to the base component. [docs]
     */
    className?: string;
    /**
     * The number of columns/offset/order on extra small devices (<576px). [docs]
     *
     * @type {{ cols: 'auto' | number} | { gutter: number } | { gutterX: number } | { gutterY: number }}
     */
    xs?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on small devices (<768px). [docs]
     *
     * @type {{ cols: 'auto' | number} | { gutter: number } | { gutterX: number } | { gutterY: number }}
     */
    sm?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on medium devices (<992px). [docs]
     *
     * @type {{ cols: 'auto' | number} | { gutter: number } | { gutterX: number } | { gutterY: number }}
     */
    md?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on large devices (<1200px). [docs]
     *
     * @type {{ cols: 'auto' | number} | { gutter: number } | { gutterX: number } | { gutterY: number }}
     */
    lg?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on X-Large devices (<1400px). [docs]
     *
     * @type {{ cols: 'auto' | number} | { gutter: number } | { gutterX: number } | { gutterY: number }}
     */
    xl?: 'auto' | number | boolean | BPObject;
    /**
     * The number of columns/offset/order on XX-Large devices (≥1400px). [docs]
     *
     * @type {{ cols: 'auto' | number} | { gutter: number } | { gutterX: number } | { gutterY: number }}
     */
    xxl?: 'auto' | number | boolean | BPObject;
}
export declare const CRow: React.ForwardRefExoticComponent<CRowProps & React.RefAttributes<HTMLDivElement>>;
