import React, { ElementType, HTMLAttributes } from 'react';
import { Colors } from '../Types';
export interface CToastProps extends Omit<HTMLAttributes<HTMLDivElement>, 'title'> {
    /**
     * Auto hide the toast. [docs]
     *
     * @default true
     */
    autohide?: boolean;
    /**
     * A string of all className you want applied to the base component. [docs]
     */
    className?: string;
    /**
     * Sets the color context of the component to one of CoreUI’s themed colors. [docs]
     *
     * @type 'primary' | 'secondary' | 'success' | 'danger' | 'warning' | 'info' | 'dark' | 'light' | string
     * @default 'primary'
     */
    color?: Colors;
    /**
     * Delay hiding the toast (ms). [docs]
     */
    delay?: number;
    /**
     * Optionally add a close button to component and allow it to self dismiss. [docs]
     *
     * @default true
     */
    dismissible?: boolean;
    icon?: string | ElementType;
    key?: number;
    time?: string;
    /**
     * Title node for your component. [docs]
     */
    title?: string | ElementType;
    /**
     * Toggle the visibility of component. [docs]
     *
     * @default true
     */
    visible?: boolean;
    /**
     * Method called before the dissmiss animation has started. [docs]
     */
    onDismiss?: () => void;
}
export declare const CToast: React.ForwardRefExoticComponent<CToastProps & React.RefAttributes<HTMLDivElement>>;
